coef.nlsr: Output model coefficients for nlsr object.
Description
coef.nlsr extracts and displays the coefficients for a model
estimated by nlxb or nlfb in the nlsr structured
object.
Usage
# S3 method for nlsr
coef(object, ...)
Value
returns the coefficients from the nlsr object.
Arguments
- object
An object of class 'nlsr'
- ...
Any data needed for the function. We do not know of any!
Author
John C Nash <nashjc@uottawa.ca>
Details
coef.nlsr extracts and displays the coefficients for a model
estimated by nlxb or nlfb.