Learn R Programming

nlsr (version 2019.9.7)

coef.nlsr: Output model coefficients for nlsr object.

Description

coef.nlsr extracts and displays the coefficients for a model estimated by nlxb or nlfb in the nlsr structured object.

Usage

# S3 method for nlsr
coef(object, ...)

Arguments

object

An object of class 'nlsr'

…

Any data needed for the function. We do not know of any!

Value

returns the coefficients from the nlsr object.

Details

coef.nlsr extracts and displays the coefficients for a model estimated by nlxb or nlfb.

See Also

Function nls(), packages optim and optimx.